@@ -9,7 +9,7 @@
 package WebService::HashiCorp::Vault;
 
 use Moo;
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.01'; # VERSION
 
 extends 'WebService::HashiCorp::Vault::Base';
 use namespace::clean;
@@ -17,6 +17,7 @@ use namespace::clean;
 use WebService::HashiCorp::Vault::Secret::Cassandra;
 use WebService::HashiCorp::Vault::Secret::Cubbyhole;
 use WebService::HashiCorp::Vault::Secret::Generic;
+use WebService::HashiCorp::Vault::Secret::Kvv2;
 use WebService::HashiCorp::Vault::Secret::MongoDB;
 use WebService::HashiCorp::Vault::Secret::MSSQL;
 use WebService::HashiCorp::Vault::Secret::MySQL;
@@ -35,6 +36,7 @@ use WebService::HashiCorp::Vault::Sys;
         consul     => 'Consul',
         cubbyhole  => 'Cubbyhole',
         generic    => 'Generic',
+        kvv2       => 'Kvv2',
         mongodb    => 'MongoDB',
         mssql      => 'MsSQL',
         mysql      => 'MySQL',
@@ -48,6 +50,7 @@ use WebService::HashiCorp::Vault::Sys;
 sub secret {
     my $self = shift;
     my %args = @_;
+    $args{approle}  = $self->approle();
     $args{token}    = $self->token();
     $args{version}  = $self->version();
     $args{base_url} = $self->base_url();
@@ -90,7 +93,7 @@ WebService::HashiCorp::Vault - Perl API for HashiCorp's Vault
 
 =head1 VERSION
 
-version 0.005
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -111,15 +114,15 @@ A perl API for convenience in using HashiCorp's Vault server software.
 
 Vault secures, stores, and tightly controls access to tokens, passwords, certificates, API keys, and other secrets in modern computing. Vault handles leasing, key revocation, key rolling, and auditing. Through a unified API, users can access an encrypted Key/Value store and network encryption-as-a-service, or generate AWS IAM/STS credentials, SQL/NoSQL databases, X.509 certificates, SSH credentials, and more.
 
-=head1 ALPHA STATUS WARNING
+=head1 BETA STATUS NOTICE
 
-This API software is an Alpha release, which I am published for people to comment on and provide pull requests.
+This API software is a I<Beta> release, which I am published for people to comment on and provide pull requests.
 
-The API will change as I try to come up with something that "feels right".
+I am now fairly happy with the API and am unlikely to make any drastic changes.
 
-So saying that, if something is strange, please send me feedback how it would be nicer!
+But if something feels strange, please send me feedback how it would be nicer!
 
-Unfortunatly the "official" API's for other languages aren't much to go on. They are barely more than a small wrapper around HTTP and JSON encoding/decoding.
+Alas, the "official" API's for other languages aren't much to go on. They are barely more than a small wrapper around HTTP and JSON encoding/decoding. I have tried to do better.
 
 =head1 METHODS
 
@@ -151,6 +154,8 @@ Here are the currently supported options:
 
 =item L<Generic|WebService::HashiCorp::Vault::Secret::Generic>
 
+=item L<Generic|WebService::HashiCorp::Vault::Secret::Kvv2>
+
 =item L<MongoDB|WebService::HashiCorp::Vault::Secret::MongoDB>
 
 =item L<MSSQL|WebService::HashiCorp::Vault::Secret::MSSQL>
@@ -202,11 +207,11 @@ L<Vault Project|https://www.vaultproject.io/>
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@bytefoundry.com.au>
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dean Hamstad.
+This software is copyright (c) 2021 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
