@@ -9,17 +9,54 @@
 package WebService::HashiCorp::Vault::Base;
 
 use Moo;
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.01'; # VERSION
 use namespace::clean;
 
 with 'WebService::Client';
 
 has '+base_url' => ( default => 'http://127.0.0.1:8200' );
-has token => ( is => 'ro', required => 1 );
+has token => ( is => 'rw' );
+has _token_expires => ( is => 'rw' );
+has approle => ( is => 'ro' );
 has version => ( is => 'ro', default => 'v1' );
 has mount => ( is => 'ro' );
 
-sub BUILD {
+before 'get' => sub {
+    $_[0]->_check_token();
+    $_[0]->_set_headers();
+};
+
+before 'post' => sub {
+    # Skip checking the token on a token request
+    if ($_[1] !~ m#auth/approle/login$#) {
+        $_[0]->_check_token();
+    }
+    $_[0]->_set_headers();
+};
+
+before 'put' => sub {
+    $_[0]->_check_token();
+    $_[0]->_set_headers();
+};
+
+before 'delete' => sub {
+    $_[0]->_check_token();
+    $_[0]->_set_headers();
+};
+
+sub _check_token {
+    my $self = shift;
+
+    $self->_request_token()
+        unless defined $self->token;
+
+    ## Check the token and get a new one if required
+    if (defined $self->_token_expires && (time > $self->_token_expires)) {
+        $self->_request_token()
+    }
+}
+
+sub _set_headers {
     my $self = shift;
     $self->ua->default_header(
         'X-Vault-Token' => $self->token,
@@ -41,10 +78,30 @@ sub _mkuri {
 }
 
 
-sub list {
+sub _request_token {
+    my $self = shift;
 
+    die 'Must provide either token or approle'
+        unless defined $self->approle;
+    die 'role_id missing in approle'
+        unless defined $self->approle->{role_id};
+    die 'secret_id missing in approle'
+        unless defined $self->approle->{secret_id};
+
+    my $url  =  join('/', $self->base_url, $self->version, 'auth/approle/login');
+    my $resp =  $self->post( $url , $self->approle );
+    $self->{token} = $resp->{auth}->{client_token};
+    ## Set the expiry to 1 second before acutal expiry
+    $self->_token_expires(time + $resp->{auth}->{lease_duration} - 1);
+}
+
+
+sub list {
     my ($self, $path) = @_;
 
+    $self->_check_token;
+    $self->_set_headers;
+
     my $headers = $self->_headers();
     my $url = $self->_url($path);
 
@@ -74,7 +131,7 @@ WebService::HashiCorp::Vault::Base - Perl API for HashiCorp's Vault (Base)
 
 =head1 VERSION
 
-version 0.005
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -111,7 +168,18 @@ Is read-only once you have created the object.
 
  my $token = $obj->token();
 
-The authentication token, is read-only after object is created.
+The authentication token.
+
+=head2 approle
+
+ my $obj = WebService::HashiCorp::Vault::Something->new(
+     approle => {
+        client_id => 'xxxxxxx',
+        secret => 'xxxxx',
+     }
+ );
+
+The client approle.
 
 =head2 version
 
@@ -150,11 +218,11 @@ L<WebService::HashiCorp::Vault>
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@bytefoundry.com.au>
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dean Hamstad.
+This software is copyright (c) 2021 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
