@@ -9,7 +9,7 @@
 package WebService::HashiCorp::Vault::Secret::LeasableBase;
 
 use Moo;
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.01'; # VERSION
 use namespace::clean;
 
 extends 'WebService::HashiCorp::Vault::Base';
@@ -39,7 +39,7 @@ WebService::HashiCorp::Vault::Secret::LeasableBase - Perl API for HashiCorp's Va
 
 =head1 VERSION
 
-version 0.005
+version 0.01
 
 =head1 SYNOPSIS
 
@@ -102,11 +102,11 @@ L<WebService::HashiCorp::Vault>
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@bytefoundry.com.au>
+Dean Hamstead <dean@fragfest.com.au>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dean Hamstad.
+This software is copyright (c) 2021 by Dean Hamstad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
